@@ -7,8 +7,10 @@
 #include "HMMEval.h"
 #include "Tools.h"
 #include "Sov.h"
+#include <gsl/gsl_errno.h>
 #include <gsl/gsl_statistics_double.h>
 #include <gsl/gsl_interp.h>
+#include <gsl/gsl_nan.h>
 
 //evaluation functions for hmm's, taking the sequences as arguments
 
@@ -548,6 +550,26 @@ vector<pair<string,vector<double> > >AccCov(vector<evaldat>& dat,
 }
 
 
+// lkajan: pre-1.15 behaviour
+static double my_gsl_interp_eval( const gsl_interp * interp,
+	const double xa[], const double ya[], double x,
+	gsl_interp_accel * a )
+{
+	double y;
+	int status;
+
+	status = interp->type->eval (interp->state, xa, ya, interp->size, x, a, &y);
+
+#define DISCARD_STATUS(s) if ((s) != GSL_SUCCESS) { GSL_ERROR_VAL("interpolation error", (s), GSL_NAN); }
+
+	DISCARD_STATUS(status);
+
+#undef DISCARD_STATUS
+
+	return y;
+}
+
+
 pair<double, double> CalcAccCovFromZ(double& zscore){
 
 	gsl_interp_accel *accel = gsl_interp_accel_alloc();
@@ -565,9 +587,11 @@ pair<double, double> CalcAccCovFromZ(double& zscore){
 	gsl_interp_init (accp, z, acc, size);
 	gsl_interp_init (covp, z, cov, size);
 
+	// lkajan: with GSL-1.15 gsl_interp_eval can no longer be used to extrapolate (gsl: interp.c:150: ERROR: interpolation error).
+	int status;
 	double 
-		acci = gsl_interp_eval(accp, z, acc, zscore, accel),
-		covi = gsl_interp_eval(covp, z, cov, zscore, accel);
+		acci = my_gsl_interp_eval(accp, z, acc, zscore, accel),
+		covi = my_gsl_interp_eval(covp, z, cov, zscore, accel);
 
 	acci = acci > 100.0 ? 100.0 : acci;
 	covi = covi > 100.0 ? 100.0 : covi;
